==> imp-doc-2.0.1.tar.gz: html/namespaceIMP.js <==
var namespaceIMP =
[
    [ "algebra", "namespaceIMP_1_1algebra.html", "namespaceIMP_1_1algebra" ],
    [ "atom", "namespaceIMP_1_1atom.html", "namespaceIMP_1_1atom" ],
    [ "base", "namespaceIMP_1_1base.html", "namespaceIMP_1_1base" ],
    [ "benchmark", "namespaceIMP_1_1benchmark.html", "namespaceIMP_1_1benchmark" ],
    [ "cgal", "namespaceIMP_1_1cgal.html", null ],
    [ "cnmultifit", "namespaceIMP_1_1cnmultifit.html", "namespaceIMP_1_1cnmultifit" ],
    [ "container", "namespaceIMP_1_1container.html", "namespaceIMP_1_1container" ],
    [ "core", "namespaceIMP_1_1core.html", "namespaceIMP_1_1core" ],
    [ "display", "namespaceIMP_1_1display.html", "namespaceIMP_1_1display" ],
    [ "domino", "namespaceIMP_1_1domino.html", "namespaceIMP_1_1domino" ],
    [ "em", "namespaceIMP_1_1em.html", "namespaceIMP_1_1em" ],
    [ "em2d", "namespaceIMP_1_1em2d.html", "namespaceIMP_1_1em2d" ],
    [ "example", "namespaceIMP_1_1example.html", "namespaceIMP_1_1example" ],
    [ "gsl", "namespaceIMP_1_1gsl.html", "namespaceIMP_1_1gsl" ],
    [ "isd", "namespaceIMP_1_1isd.html", "namespaceIMP_1_1isd" ],
    [ "kernel", "namespaceIMP_1_1kernel.html", "namespaceIMP_1_1kernel" ],
    [ "kmeans", "namespaceIMP_1_1kmeans.html", "namespaceIMP_1_1kmeans" ],
    [ "misc", "namespaceIMP_1_1misc.html", "namespaceIMP_1_1misc" ],
    [ "modeller", "namespaceIMP_1_1modeller.html", "namespaceIMP_1_1modeller" ],
    [ "multifit", "namespaceIMP_1_1multifit.html", "namespaceIMP_1_1multifit" ],
    [ "parallel", "namespaceIMP_1_1parallel.html", "namespaceIMP_1_1parallel" ],
    [ "pepdock", "namespaceIMP_1_1pepdock.html", null ],
    [ "restrainer", "namespaceIMP_1_1restrainer.html", "namespaceIMP_1_1restrainer" ],
    [ "rmf", "namespaceIMP_1_1rmf.html", "namespaceIMP_1_1rmf" ],
    [ "rotamer", "namespaceIMP_1_1rotamer.html", "namespaceIMP_1_1rotamer" ],
    [ "saxs", "namespaceIMP_1_1saxs.html", "namespaceIMP_1_1saxs" ],
    [ "score_functor", "namespaceIMP_1_1score__functor.html", "namespaceIMP_1_1score__functor" ],
    [ "scratch", "namespaceIMP_1_1scratch.html", null ],
    [ "statistics", "namespaceIMP_1_1statistics.html", "namespaceIMP_1_1statistics" ],
    [ "system", "namespaceIMP_1_1system.html", null ],
    [ "test", null, [
      [ "ApplicationTestCase", "classIMP_1_1test_1_1ApplicationTestCase.html", "classIMP_1_1test_1_1ApplicationTestCase" ],
      [ "DirectorObjectChecker", "classIMP_1_1test_1_1DirectorObjectChecker.html", "classIMP_1_1test_1_1DirectorObjectChecker" ],
      [ "RefCountChecker", "classIMP_1_1test_1_1RefCountChecker.html", "classIMP_1_1test_1_1RefCountChecker" ],
      [ "RunInTempDir", "classIMP_1_1test_1_1RunInTempDir.html", null ],
      [ "TestCase", "classIMP_1_1test_1_1TestCase.html", "classIMP_1_1test_1_1TestCase" ]
    ] ]
];

==> imp-doc-2.1.1.tar.gz: html/namespaceIMP.js <==
var namespaceIMP =
[
    [ "algebra", "namespaceIMP_1_1algebra.html", "namespaceIMP_1_1algebra" ],
    [ "atom", "namespaceIMP_1_1atom.html", "namespaceIMP_1_1atom" ],
    [ "base", "namespaceIMP_1_1base.html", "namespaceIMP_1_1base" ],
    [ "benchmark", "namespaceIMP_1_1benchmark.html", "namespaceIMP_1_1benchmark" ],
    [ "cgal", "namespaceIMP_1_1cgal.html", null ],
    [ "cnmultifit", "namespaceIMP_1_1cnmultifit.html", "namespaceIMP_1_1cnmultifit" ],
    [ "container", "namespaceIMP_1_1container.html", "namespaceIMP_1_1container" ],
    [ "core", "namespaceIMP_1_1core.html", "namespaceIMP_1_1core" ],
    [ "display", "namespaceIMP_1_1display.html", "namespaceIMP_1_1display" ],
    [ "domino", "namespaceIMP_1_1domino.html", "namespaceIMP_1_1domino" ],
    [ "em", "namespaceIMP_1_1em.html", "namespaceIMP_1_1em" ],
    [ "em2d", "namespaceIMP_1_1em2d.html", "namespaceIMP_1_1em2d" ],
    [ "example", "namespaceIMP_1_1example.html", "namespaceIMP_1_1example" ],
    [ "gsl", "namespaceIMP_1_1gsl.html", "namespaceIMP_1_1gsl" ],
    [ "isd", "namespaceIMP_1_1isd.html", "namespaceIMP_1_1isd" ],
    [ "kernel", "namespaceIMP_1_1kernel.html", "namespaceIMP_1_1kernel" ],
    [ "kinematics", "namespaceIMP_1_1kinematics.html", "namespaceIMP_1_1kinematics" ],
    [ "kmeans", "namespaceIMP_1_1kmeans.html", "namespaceIMP_1_1kmeans" ],
    [ "misc", "namespaceIMP_1_1misc.html", "namespaceIMP_1_1misc" ],
    [ "modeller", "namespaceIMP_1_1modeller.html", "namespaceIMP_1_1modeller" ],
    [ "mpi", "namespaceIMP_1_1mpi.html", "namespaceIMP_1_1mpi" ],
    [ "multifit", "namespaceIMP_1_1multifit.html", "namespaceIMP_1_1multifit" ],
    [ "parallel", "namespaceIMP_1_1parallel.html", "namespaceIMP_1_1parallel" ],
    [ "pepdock", "namespaceIMP_1_1pepdock.html", null ],
    [ "restrainer", "namespaceIMP_1_1restrainer.html", "namespaceIMP_1_1restrainer" ],
    [ "rmf", "namespaceIMP_1_1rmf.html", "namespaceIMP_1_1rmf" ],
    [ "rotamer", "namespaceIMP_1_1rotamer.html", "namespaceIMP_1_1rotamer" ],
    [ "saxs", "namespaceIMP_1_1saxs.html", "namespaceIMP_1_1saxs" ],
    [ "score_functor", "namespaceIMP_1_1score__functor.html", "namespaceIMP_1_1score__functor" ],
    [ "scratch", "namespaceIMP_1_1scratch.html", null ],
    [ "statistics", "namespaceIMP_1_1statistics.html", "namespaceIMP_1_1statistics" ],
    [ "symmetry", "namespaceIMP_1_1symmetry.html", "namespaceIMP_1_1symmetry" ],
    [ "system", "namespaceIMP_1_1system.html", null ],
    [ "test", "namespaceIMP_1_1test.html", "namespaceIMP_1_1test" ]
];
